# Changelog

Versions follow [Semantic Versioning](https://semver.org) (`<major>.<minor>.<patch>`)
and the format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [0.1.1](https://github.com/tahv/types-maya/releases/tag/0.1.1) - 2025-02-25

- Add `maya.api.OpenMaya.MDagModifier`.
- Add incomplete `maya.OpenMaya*` modules.

## [0.1.0](https://github.com/tahv/types-maya/releases/tag/0.1.0) - 2025-02-23

- Initial release.
